@@ -31,7 +31,7 @@ limitations under the License.
 =head1 NAME
 
 Bio::EnsEMBL::BaseAlignFeature - Baseclass providing a common abstract
-implmentation for alignment features
+implementation for alignment features
 
 =head1 SYNOPSIS
 
@@ -142,8 +142,8 @@ implmentation for alignment features
 
 
 package Bio::EnsEMBL::BaseAlignFeature;
-$Bio::EnsEMBL::BaseAlignFeature::VERSION = '112.0_54'; # TRIAL
-$Bio::EnsEMBL::BaseAlignFeature::VERSION = '112.054';
+$Bio::EnsEMBL::BaseAlignFeature::VERSION = '112.0_55'; # TRIAL
+$Bio::EnsEMBL::BaseAlignFeature::VERSION = '112.055';
 use Bio::EnsEMBL::FeaturePair;
 use Bio::EnsEMBL::Utils::Argument qw(rearrange);
 use Bio::EnsEMBL::Utils::Exception qw(throw warning);
